\name{all.regs}
\alias{all.regs}
\title{
  Goodness of fit measures for a regression hierarchy
}
\description{
  Calculates goodness of fit measures for regressions of a single
  dependent variable to all combinations of N independent variables
}
\usage{
all.regs(y, xcan, family = "gaussian", gof = "RMSPE", print.vars = FALSE)
}
\arguments{
  \item{y}{
    a vector containing the dependent variables
  }
  
  \item{xcan}{
    a dataframe containing the n independent variables
  }
  
  \item{family}{
    family argument of \code{glm}
  }

  \item{gof}{
    Goodness-of-fit measure.  Currently "RMSPE", Root-mean-square
    'prediction' error,  "logLik", Log-Likelihood or "Rsqu", R-squared
    }

  \item{print.vars}{
    if FALSE, the function returns a vector of goodness-of-fit measures. If
    TRUE, a data frame is returned with first column listing variable
    combinations and the second column listing goodness-of-fit measures.
    }
  }

\details{
This function calculates goodness of fit measures for the entire
hierarchy of models using all combinations of N dependent variables, and
returns them as an ordered list ready for input into the function
\code{partition}.      
}

\value{
  \item{gfs}{
    If print.vars is FALSE, a vector of goodness of fit measures for all
    combinations of independent varaiables in the hierarchy or, if
    print.vars is TRUE, a data frame listing all combinations of
    independent variables in the first column in ascending order, and
    the corresponding goodness of fit measure for the model using those
    variables
  }
}
\author{
  Chris Walsh \email{Chris.Walsh@sci.monash.edu.au}.
}

\see also{
  \code{hier.part}, \code{partition}, \code{glm}, \code{rand.hp}
  }
 \examples{
           #linear regression with four independent variables
           data(urban)
           env <- urban[,3:6]
           all.regs(urban$chl, env, fam = "gaussian", gof = "Rsqu",
                    print.vars = TRUE)

           #logistic regression with four independent variables
           data(urban1)
           env1 <- urban1[,2:5]
           all.regs(urban1$pa, env1, fam = "binomial", gof = "logLik")
}
\keyword{}

\eof
\name{combos}
\alias{combos}
\title{
  All combinations of a hierarchy of models of n variables
}
\description{
  Lists a matrix of combinations of 1 to n variables in ascending order
}
\usage{
  combos(n)
}
\arguments{
  \item{n}{
    an integer: the number of variables
  }
  }

\details{
Lists hierarchy of all possible combinations of n variables in ascending
order, starting with 1 variable, then all combinations of 2 variables,
and so on until the one combination with all n variables.  This function
is used by \code{all.regs} to structure the models required for
hierarchical partioning
}

\value{
  a list containing
  \item{ragged}{
    a matrix with zeroes in empty elements and 1 in column 1, 2 in
    column 2 ... n in column n for full elements
  }

  \item{binary}{
    a matrix as for ragged, but with 1 in all full elements
    }
}
\author{
  Chris Walsh \email{Chris.Walsh@sci.monash.edu.au} 
}

\see also{
  \code{all.regs}
  }

\keyword{}

\eof
\name{hier.part}
\alias{hier.part}
\title{
  Goodness of fit calculation and hierarchical partitioning
}
\description{
  Partitions variance in a multivariate dataset
}
\usage{
hier.part(y, xcan, family = "gaussian", gof = "RMSPE", barplot = TRUE)
}
\arguments{
  \item{y}{
    a vector containing the dependent variables
  }
  
  \item{xcan}{
    a dataframe containing the n independent variables
  }
  
  \item{family}{
    family argument of \code{glm}
  }

  \item{gof}{
    Goodness-of-fit measure.  Currently "RMSPE", Root-mean-square
    'prediction' error, "logLik", Log-Likelihood or "Rsqu", R-squared
    }

    \item{barplot}{
    If TRUE, a barplot of I and J for each variable is plotted expressed
    as percentage of total explained variance.
    }
  }

\details{
This function calculates goodness of fit measures for the entire
hierarchy of models using all combinations of N independent variables
using the function \code{all.regs}.  It takes the list of goodness
of fit measures and, using the \code{partition} function, applies the
hierarchical partitioning algorithm of Chevan and Sutherland (1991)
to return a simple table listing of each variable, its independent
contribution (I) and its conjoint contribution with all other variables
(J).

At this stage, the partition routine will not run for more than 12
independent variables.  
}

\value{
  a list containing
  \item{gfs}{
    a data frame or vector listing all combinations of independent
    variables in the first column in ascending order, and the
    corresponding goodness of fit measure for the model using those
    variables
  }

  \item{IJ}{
    a data frame of I, the independent and J the joint
    contribution for each independent variable
  }

  \item{IJ.perc}{
    a data frame of I and J expressed as percentage of
    total explained variance
  }
}
\author{
  Chris Walsh \email{Chris.Walsh@sci.monash.edu.au} using c and fortran
  code written by Ralph MacNally \email{Ralph.MacNally@sci.monash.edu.au}.
}
\references{
  Chevan, A. and Sutherland, M. (1991) Hierarchical Partitioning. The
  American Statistician 45: 90-96.
  Mac Nally, R. (2000) Regression and model building in conservation
  biology, biogeography and ecology: the distinction between and
  reconciliation of 'predictive' and 'explanatory' models. Biodiversity
  and Conservation 9: 655-671.
}
\see also{
  \code{all.regs}, \code{partition}, \code{glm}, \code{rand.hp}
  }
 \examples{
           #linear regression with four independent variables
           data(urban)
           env <- urban[,3:6]
           hier.part(urban$chl, env, fam = "gaussian", gof = "Rsqu")

           #logistic regression with four independent variables
           data(urban1)
           env1 <- urban1[,2:5]
           hier.part(urban1$pa, env1, fam = "binomial", gof = "logLik")
}
\keyword{}

\eof
\name{hier.part.data}
\alias{urban}
\alias{urban1}
\alias{chevan}
\title{
  Example data for hier.part
}
\description{
  Example data sets for hier.part package.
  }
\usage{
  data(urban)
  data(urban1)
  data(chevan)
}
\details{
    urban.txt

    Mean chlorophyll data (chl) for at 16 sites on 16 streams, with four
    catchment variables for each site (fimp, fconn, sep, unseal)
  
    urban1.txt

    Presence-absence data (pa) for a species in 58 sites, with four
    catchment variables as above

    chevan.txt

    Chi-squared (chisq) and R-squared (rsqu) for logistic and linear
    regression example from Chevan and Sutherland (1991)
}
\references{
  Chevan, A. and Sutherland, M. (1991) Hierarchical Partitioning. The
  American Statistician 45: 90-96  
}
\author{
  Chris Walsh \email{Chris.Walsh@sci.monash.edu.au}
}
\keyword{datasets}







\eof
\name{hier.part.internal}
\alias{combos1}
\alias{current.model}

\title{
  Internal functions for hier.part
}
\description{
  Internal functions for hier.part
}
\keyword{internal}
\eof
\name{partition}
\alias{partition}
\title{
  Hierarchical partitioning from a list of goodness of fit measures 
}
\description{
  Partitions variance in a multivariate dataset from a list of goodness
  of fit measures
}
\usage{
partition(gfs, pcan, var.names = NULL)
}
\arguments{
  \item{gfs}{
    an array as outputted by the function \code{all.regs} or a vector of
    goodness of fit measures from a hierarchy of regressions based on pcan
    variables in ascending order (as produced by function \code{combos},
    but also including the null model as the first element)
  }
  
  \item{pcan}{
    the number of variables from which the hierarchy was constructed
    (maximum = 12)
  }
  
  \item{var.names}{
    an array of pcan variable names, if required
  }
  }

\details{
This function applies the hierarchical partitioning algorithm of Chevan
and Sutherland (1991) to return a simple table listing of each variable,
its independent contribution (I) and its conjoint contribution with all
other variables (J).  The output is identical to the function
\code{hier.part}, which takes the dependent and independent variable
data as its input

At this stage, the partition routine will not run for more than 12
independent variables.
}

\value{
  a list containing
  \item{gfs}{
    a data frame listing all combinations of independent
    variables in the first column in ascending order, and the
    corresponding goodness of fit measure for the model using those
    variables
  }

  \item{IJ}{
    a data frame of I, the independent and J the joint
    contribution for each independent variable
  }

  \item{IJ.perc}{
    a data frame of I and J expressed as percentage of
    total explained variance
  }
}
\author{
  Chris Walsh \email{Chris.Walsh@sci.monash.edu.au} using c and fortran
  code written by Ralph MacNally \email{Ralph.MacNally@sci.monash.edu.au}.
}
\references{
  Chevan, and Sutherland (1991) The American Statistician 45: 90
}
\see also{
  \code{all.regs}, \code{partition}, \code{glm}, \code{rand.hp}
  }
 \examples{
           #linear regression with four independent variables
           data(urban)
           env <- urban[,3:6]
           gofs <- all.regs(urban$chl, env,
                            fam = "gaussian", gof = "Rsqu")
           partition(gofs, pcan = 4, var.names = names(urban[,3:6]))

           #hierarchical partitioning of logistic and linear regression
           #goodness of fit measures from Chevan and Sutherland (1991) 
           data(chevan)
           partition(chevan$chisq, pcan = 4)
           partition(chevan$rsqu, pcan = 4)
}
\keyword{}

\eof
\name{rand.hp}
\alias{rand.hp}
\title{
  Randomization test for hierarchical partitioning
}
\description{
  Randomizes elements in each column in xcan and recalculates
  \code{hier.part} num.reps times
}
\usage{
 rand.hp(y, xcan, family = "gaussian", gof = "RMSPE",
                    num.reps = 100)
}
\arguments{
  \item{y}{
    a vector containing the dependent variables
  }
  
  \item{xcan}{
    a dataframe containing the n independent variables
  }
  
  \item{family}{
    family argument of \code{glm}
  }

  \item{gof}{
    Goodness-of-fit measure.  Currently "RMSPE", Root-mean-square
    'Prediction' error, "NLL", Negative log Likelihood or "Rsqu",
    R-squared
  }

  \item{num.reps}{
    Number of repeated randomizations
    }
  }

\details{
This function is a randomization routine for the \code{hier.part}
function which returns a matrix of I values (the independent
contribution towards explained variance in a multivariate dataset) for
all values from "num.reps" randomizations. For each randomization, the
values in each variable (i.e each column of xcan) are randomized
independently, and hier.part is run on the randomized xcan.  As well as
the randomized I matrix, the function returns a summary table listing
the observed I values, the 95th and 99th percentile values of I for
the randomized dataset.   
}

\value{
  a list containing
  \item{Irands}{
    matrix of num.reps + 1  rows of I values for each dependent
    variable.  The first row contains the observed I values and the
    remaining num.reps rows contains the I values returned for each
    randomization.  
  }
  \item{Iprobs}{
    data.frame of observed I values for each variable, Z-scores for the
    generated distribution of randomized Is and an indication of
    statistical significance.  Z-scores are cacluated as
    (observed - mean(randomizations))/sd(randomizations),
    and statistical significance (*) is based on upper 0.95 confidence
    limit (Z >= 1.65).
    }
}
\author{
  Chris Walsh \email{Chris.Walsh@sci.monash.edu.au}.
}
\references{
  Mac Nally, R. (2000) Regression and model building in conservation
  biology, biogeography and ecology: the distinction between and
  reconciliation of 'predictive' and 'explanatory' models. Biodiversity
  and Conservation 9: 655-671.
  MacNally, R. (2002) Multiple regression and inference in conservation
  biology and ecology: further comments on identifying important
  predictor variables. Biodiversity and Conservation 11: 1397-1401.
  }

\see also{
  \code{hier.part}, \code{partition}, \code{glm}
  }
  \examples{
            #linear regression with four independent variables
            data(urban)
            env <- urban[,3:6]
            rand.hp(urban$chl, env, fam = "gaussian", gof = "Rsqu")$Iprobs

            #logistic regression with four independent variables
            data(urban1)
            env1 <- urban1[,2:5]
            rand.hp(urban1$pa, env1, fam = "binomial", gof = "logLik")$Iprobs

}
\keyword{}

\eof
